record.SaxToXmlHandler

|  | ## Cheshire3 Object Model: Class SaxToXmlHandler

Module record :: Class SaxToXmlHandler

## Class SaxToXmlHandler
source code

Instance Methods

initState(self)
startPrefixMapping(self, pref, uri)
startElement(self, name, attribs={})
endElement(self, name)
_getPrefix(self, ns)
startElementNS(self, n, qn=None, attrs={})
endElementNS(self, n, qn=None)
characters(self, text, zero=0, length=0)
get_raw(self)

Class Variables

xml |
currNs |
newNamespaces |

Method Details

### initState(self) | source code

### startPrefixMapping(self, pref, uri) | source code

### startElement(self, name, attribs={}) | source code

### endElement(self, name) | source code

### _getPrefix(self, ns) | source code

### startElementNS(self, n, qn=None, attrs={}) | source code

### endElementNS(self, n, qn=None) | source code

### characters(self, text, zero=0, length=0) | source code

### get_raw(self) | source code

Class Variable Details

    ### xml Value:
        []

    ### currNs Value:
        0

    ### newNamespaces Value:
        {}